@@ -1,6 +1,7 @@
 #!/usr/bin/env python
 import sys
 
+from .enums import TextMode, XPos, YPos
 from .fpdf import (
     FPDF,
     FPDFException,
@@ -39,6 +40,8 @@ __all__ = [
     "__license__",
     # Classes
     "FPDF",
+    "XPos",
+    "YPos",
     "Template",
     "FlexTemplate",
     "TitleStyle",
